@@ -157,7 +157,16 @@
 #' used as independent variable for predicting individual tree morality?
 #' @param intermediate_print logical, if TRUE intermediate steps will be printed
 #' while MLFS is running
-#'
+#' @param use_max_size_threshold logical - should the principle of maxium size
+#' be applied?
+#' @param mortality_bias_adjusted Logical (length-one). If `TRUE` (default),
+#'   applies a simple bias fix so large trees aren’t over-removed. The frequency
+#'   of adjustment is controlled by the `bias_adj_factor` argument. If `FALSE`,
+#'   predicted probabilities are left unchanged.
+#' @param bias_adj_factor Integer (>= 2). Controls how sparsely you reduce
+#' death probabilities among the top-ranked trees. Starting from the 3rd row,
+#' every `bias_adj_factor`-th tree has its probability set to zero—so `2` keeps
+#' every second high-risk tree alive, `3` every third, and so on.
 #' @return a list of class mlfs with at least 15 elements:
 #' \enumerate{
 #'  \item $sim_results - a data frame with the simulation results
@@ -276,7 +285,12 @@ MLFS <- function(data_NFI, data_site,
                  export_csv = FALSE,
                  sim_export_mode = TRUE,
                  include_mortality_BAI = TRUE,
-                 intermediate_print = FALSE
+                 intermediate_print = FALSE,
+                 use_max_size_threshold = FALSE,
+
+                 mortality_bias_adjusted = TRUE,
+                 bias_adj_factor = 3
+
                  ){
 
   # Define global variables
@@ -380,7 +394,7 @@ MLFS <- function(data_NFI, data_site,
   site_vars <- colnames(data_site)[!(colnames(data_site) %in% c("plotID"))]
 
   # merge NFI and site descriptors
-  data <- merge(data_NFI, data_site, by = "plotID")
+  data <- merge(data_NFI, data_site, by = "plotID", all.x = TRUE)
 
   # remove the objects to make free space
   rm(data_NFI)
@@ -399,13 +413,28 @@ MLFS <- function(data_NFI, data_site,
   # Calculate measurement thresholds in terms of basal area
   measurement_thresholds$BA_threshold <- ((measurement_thresholds$DBH_threshold/2)^2 * pi)/10000
 
-  data <- data %>% mutate(weight = ifelse(BA >= max(measurement_thresholds$BA_threshold),
-                                          measurement_thresholds[, "weight"][which.max(measurement_thresholds$BA_threshold)],
-                                          measurement_thresholds[, "weight"][which.min(measurement_thresholds$BA_threshold)]),
+  # data <- data %>% mutate(weight = ifelse(BA >= max(measurement_thresholds$BA_threshold),
+  #                                        measurement_thresholds[, "weight"][which.max(measurement_thresholds$BA_threshold)],
+  #                                        measurement_thresholds[, "weight"][which.min(measurement_thresholds$BA_threshold)]),
+  #
+  #                        DBH_threshold = ifelse(BA >= max(measurement_thresholds$BA_threshold),
+  #                                              measurement_thresholds[, "DBH_threshold"][which.max(measurement_thresholds$BA_threshold)],
+  #                                               measurement_thresholds[, "DBH_threshold"][which.min(measurement_thresholds$BA_threshold)]))
+
+  data <- data %>%
+    mutate(
+      weight = ifelse(
+        BA >= max(measurement_thresholds$BA_threshold),
+        measurement_thresholds$weight[which.max(measurement_thresholds$BA_threshold)],
+        measurement_thresholds$weight[which.min(measurement_thresholds$BA_threshold)]
+      ),
+      DBH_threshold = ifelse(
+        BA >= max(measurement_thresholds$BA_threshold),
+        measurement_thresholds$DBH_threshold[which.max(measurement_thresholds$BA_threshold)],
+        measurement_thresholds$DBH_threshold[which.min(measurement_thresholds$BA_threshold)]
+      )
+    )
 
-                          DBH_threshold = ifelse(BA >= max(measurement_thresholds$BA_threshold),
-                                                 measurement_thresholds[, "DBH_threshold"][which.max(measurement_thresholds$BA_threshold)],
-                                                 measurement_thresholds[, "DBH_threshold"][which.min(measurement_thresholds$BA_threshold)]))
 
   # In case area correction factors are provided we use them to correct plot weights
   if (!is.null(area_correction)){
@@ -566,6 +595,11 @@ MLFS <- function(data_NFI, data_site,
 
   initial_df <- data
 
+  current_max_year <- max(initial_df$year)
+
+  # Here we subset and keep only the most recent NFI year
+  initial_df <- dplyr::filter(initial_df, year == current_max_year)
+
   # remove data
   rm(data)
 
@@ -617,7 +651,7 @@ MLFS <- function(data_NFI, data_site,
 
     }
 
-    initial_df <- volume_functions(df = initial_df, df_volumeF_parameters = df_volumeF_parameters)
+    initial_df_ <- volume_functions(df = initial_df, df_volumeF_parameters = df_volumeF_parameters)
 
   } else if (volume_calculation == "tariffs"){
 
@@ -1051,7 +1085,10 @@ MLFS <- function(data_NFI, data_site,
                                            df_max_size = max_size_data,
                                            ingrowth_codes = ingrowth_codes,
                                            include_mortality_BAI = include_mortality_BAI,
-                                           intermediate_print = intermediate_print
+                                           intermediate_print = intermediate_print,
+                                           use_max_size_threshold = use_max_size_threshold,
+                                           mortality_bias_adjusted = mortality_bias_adjusted,
+                                           bias_adj_factor = bias_adj_factor
                                            )
 
     initial_df <- mortality_outputs$predicted_mortality
